@@ -18,6 +18,8 @@ if sys.version_info >= (3, 8):
 else:
     from typing_extensions import Literal
 
+import sys
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -30,6 +32,7 @@ __all__ = (
     "AccelerationSettingsTypeDef",
     "AiffSettingsTypeDef",
     "AncillarySourceSettingsTypeDef",
+    "AudioChannelTaggingSettingsTypeDef",
     "AudioCodecSettingsTypeDef",
     "AudioDescriptionTypeDef",
     "AudioNormalizationSettingsTypeDef",
@@ -251,6 +254,30 @@ AncillarySourceSettingsTypeDef = TypedDict(
     total=False,
 )
 
+AudioChannelTaggingSettingsTypeDef = TypedDict(
+    "AudioChannelTaggingSettingsTypeDef",
+    {
+        "ChannelTag": Literal[
+            "L",
+            "R",
+            "C",
+            "LFE",
+            "LS",
+            "RS",
+            "LC",
+            "RC",
+            "CS",
+            "LSD",
+            "RSD",
+            "TCS",
+            "VHL",
+            "VHC",
+            "VHR",
+        ]
+    },
+    total=False,
+)
+
 AudioCodecSettingsTypeDef = TypedDict(
     "AudioCodecSettingsTypeDef",
     {
@@ -284,6 +311,7 @@ AudioCodecSettingsTypeDef = TypedDict(
 AudioDescriptionTypeDef = TypedDict(
     "AudioDescriptionTypeDef",
     {
+        "AudioChannelTaggingSettings": "AudioChannelTaggingSettingsTypeDef",
         "AudioNormalizationSettings": "AudioNormalizationSettingsTypeDef",
         "AudioSourceName": str,
         "AudioType": int,
@@ -2156,6 +2184,7 @@ HlsGroupSettingsTypeDef = TypedDict(
     {
         "AdMarkers": List[Literal["ELEMENTAL", "ELEMENTAL_SCTE35"]],
         "AdditionalManifests": List["HlsAdditionalManifestTypeDef"],
+        "AudioOnlyHeader": Literal["INCLUDE", "EXCLUDE"],
         "BaseUrl": str,
         "CaptionLanguageMappings": List["HlsCaptionLanguageMappingTypeDef"],
         "CaptionLanguageSetting": Literal["INSERT", "OMIT", "NONE"],
